*====================================================================================================*
*                                  preparation.do                                                    *
*====================================================================================================*

*----------------------------------------------------------------------------------------------------*
*  Leopold & Schulz 2018, replication files                                                         			 *
*  last update: 08 March 2018                                                                        *
*  data: soeplong 1984-2015, version 32.1, release 2017                                              *
*----------------------------------------------------------------------------------------------------*


*-----------------------------------------------------------------------------*
* 1. Prepare data for Partner 1                                               *
*-----------------------------------------------------------------------------*

*-----------------------------------------------------------------------------*
* 1.1 Retrieve variables                                                      *
*-----------------------------------------------------------------------------*

* Load the main person file (pl)

use 	syear pid hid plh0171 plh0174 plh0182 pli0045	///
		pli0037 pli0038	pli0039 pli0040 pli0042 		///
		pli0043 pli0044 pli0049 ple0008  using "$data/pl.dta", clear


* Merge data from ancillary files

merge 	m:1 pid using "$data\ppfad.dta", 	 		 	///
		keepusing (sex gebjahr loc1989 migback psample) /// 
		keep (1 3) nogen
merge 	1:1 pid syear using "$data\pgen.dta", 		 	///
		keepusing (pgcasmin pgfamstd pgemplst)			/// 
		keep (1 3) nogen
merge 	1:1 pid syear using "$data\ppfadl.dta", 		///
		keepusing (parid partner) 						///
		keep (1 3) nogen
merge 	m:1 hid syear using "$data/hgen.dta", 			///
		keepusing (hgsize) 								/// 
		keep(1 3) nogen
merge 	m:1 hid syear using "$data\hl.dta",   		 	///
		keepusing (hlf0261) 							///
		keep (1 3) nogen


label language EN


*-----------------------------------------------------------------------------*
* 1.2 Select anchor respondents that can be linked to a partner in the data   *
*-----------------------------------------------------------------------------*

* Define missing values for the partner identifier variable parid

replace parid = . if parid < 0


* Identify the first married partner in the data

// Define a help variable aux that includes only partner ID's of married partners
gen aux = parid if partner == 1 

// Partner ID's increase over time; hence the minimum of aux is the first married partner
bysort pid: egen minparid = min(aux) 
label variable minparid "ID of first married partner"
drop aux

// Select only those that can be linked to a partner
keep if minparid != .
sort pid syear


*-----------------------------------------------------------------------------*
* 1.3 Remove duplicates of couples                                            *
*-----------------------------------------------------------------------------*

/*
The person main file includes all respondents. Therefore, we have duplicates 
of couples in the data. Partner 1 is linked to partner 2, and vice versa. 
To remove duplicates, we consider only the partner with the lower number on the
numeric person ID. It is irrelevant whether we choose the lower or higher number
because we consider only observations in which both partners are observed 
concurrently. 
*/

* Identify the partner with the lower person ID and keep only those
gen aux = min(pid, minparid) // minparid is the new partner identifier defined above
keep if pid == aux
drop aux

		
*-----------------------------------------------------------------------------*
* 1.4 Denote Partner 1 variables                                              *
*-----------------------------------------------------------------------------*
		
* Anchor respondent in the current data is Partner 1; mark variables by _1
order pid syear parid minparid
	foreach var of varlist hid-hlf0261 {
		rename `var' `var'_1
			}
			*

*-----------------------------------------------------------------------------*
* 1.5 Save Partner 1 data to temporary file                                   *
*-----------------------------------------------------------------------------*

save "$temp/partner_1.dta", replace


*-----------------------------------------------------------------------------*
* 2. Prepare data for Partner 2                                               *
*-----------------------------------------------------------------------------*

*-----------------------------------------------------------------------------*
* 2.1 Retrieve variables                                                      *
*-----------------------------------------------------------------------------*

* Load the main person file (pl)

use 	syear pid hid plh0171 plh0174 plh0182 pli0045	///
		pli0037 pli0038	pli0039 pli0040 pli0042 		///
		pli0043 pli0044 pli0049 ple0008  using "$data/pl.dta", clear


* Merge data from ancillary files

merge 	m:1 pid using "$data\ppfad.dta", 	 		 	///
		keepusing (sex gebjahr loc1989 migback psample) /// 
		keep (1 3) nogen
merge 	1:1 pid syear using "$data\pgen.dta", 		 	///
		keepusing (pgcasmin pgfamstd pgemplst)			/// 
		keep (1 3) nogen
merge 	1:1 pid syear using "$data\ppfadl.dta", 		///
		keepusing (parid partner) 						///
		keep (1 3) nogen
merge 	m:1 hid syear using "$data/hgen.dta", 			///
		keepusing (hgsize) 								/// 
		keep(1 3) nogen
merge 	m:1 hid syear using "$data\hl.dta",   		 	///
		keepusing (hlf0261) 							///
		keep (1 3) nogen

label language EN

	
*-----------------------------------------------------------------------------*
* 2.2 Denote Partner 2 variables                                              *
*-----------------------------------------------------------------------------*

* Define person ID of Partner 2 as ID of the first married partner of Partner 1

/*
This step prepares the linkage of partners. We rename the person identifier (pid) 
into the ID of the first married partner of Partner 1 (see above, line 125). This
identifier will match the couple. Importantly, because this is a time-invariant
linkage to the first married partner, the couple is inextricably merged over 
all observations - irrespective of later divorce.
*/

rename pid minparid 
label variable minparid "ID of first married partner"
		
* Anchor respondent in the current data is Partner 2; mark variables by _2

order minparid syear parid
	foreach var of varlist hid-hlf0261 {
		rename `var' `var'_2
			}
			*

*-----------------------------------------------------------------------------*
* 2.3 Save Partner 2 data to temporary file                                   *
*-----------------------------------------------------------------------------*

save "$temp/partner_2.dta", replace



*-----------------------------------------------------------------------------*
* 3. Match couples (Partner 1 to Partner 2)                                   *
*-----------------------------------------------------------------------------*

* Load Partner 1 file

use "$temp/partner_1.dta", clear


*-----------------------------------------------------------------------------*
* 3.1 Drop duplicates                                                         *
*-----------------------------------------------------------------------------*

/*
In very few cases (0.11 percent of observations), a partner (minparid) is the 
first married partner to more than one person in a household (changes over time). 
We drop these duplicates.
*/

duplicates drop minparid syear, force


*-----------------------------------------------------------------------------*
* 3.2 Merge from Partner 2 file                                               *
*-----------------------------------------------------------------------------*

merge 1:1 minparid syear using "$temp/partner_2.dta", keep (3) nogen
		
* Order

order 	pid syear parid minparid ///
		hid_1 hid_2				 ///
		sex_1 sex_2 			 ///
		partner_1 partner_2
		
sort pid syear	


*-----------------------------------------------------------------------------*
* 3.3 Save and erase                                                          *
*-----------------------------------------------------------------------------*

* Save

save "$temp/couples.dta", replace


* Erase temporary partner files

erase "$temp/partner_1.dta"
erase "$temp/partner_2.dta"


*-----------------------------------------------------------------------------*
* 4. Select sample                                                            *
*-----------------------------------------------------------------------------*

use "$temp/couples.dta", clear			
			
	
*-----------------------------------------------------------------------------*
* 4.1 Remove observations before first marriage                               *
*-----------------------------------------------------------------------------*

* Identify the first year observed living together

gen aux = syear if    ///
	inlist(partner_1,1,2,3,4)    /// Partner 1 reports a partner
	& inlist(partner_2,1,2,3,4)  /// Partner 2 reports a partner
	& (hid_1 == hid_2) 			 //  Both live in the same household
bysort pid (syear): egen aux1 = min(aux) // aux1 = first year in which these conditions are met


* Drop observations before this year

drop if syear < aux1
drop aux aux1


*-----------------------------------------------------------------------------*
* 4.2 Remove same-sex couples                                                 *
*-----------------------------------------------------------------------------*

gen aux = (sex_1 == sex_2)
drop if aux
drop aux
			

*-----------------------------------------------------------------------------*
* 4.3 Keep only coresidence observations	                                  *
*-----------------------------------------------------------------------------*
			
keep if hid_1 == hid_2			


*-----------------------------------------------------------------------------*
* 4.4 Drop duplicates of couples			                                  *
*-----------------------------------------------------------------------------*

rename hid_1 cid
duplicates drop cid syear, force
drop hid_2


*-----------------------------------------------------------------------------*
* 4.5 Age range								                                  *
*-----------------------------------------------------------------------------*

* Age range
gen age_1 = syear - gebjahr_1
gen age_2 = syear - gebjahr_2
egen cage = rowmean(age_1 age_2)

keep if inrange(age_1,60,85)
keep if inrange(age_2,60,85)


*-----------------------------------------------------------------------------*
* 4.6 Retired couples (both do no market work)	                              *
*-----------------------------------------------------------------------------*
keep if pgemplst_1 == 5 & pgemplst_2 == 5


*-----------------------------------------------------------------------------*
* 4.7 Survey years							                                  *
*-----------------------------------------------------------------------------*

drop if syear < 1992
drop if syear == 1993 // self-rated health observed in 1992 and anually since 1994
	
	
*-----------------------------------------------------------------------------*
* 5. Variables	                                                              *
*-----------------------------------------------------------------------------*

* Routine housework
foreach x of numlist 1/2 {			
replace pli0043_`x' = 0 if pli0043_`x' == -2
replace pli0043_`x' = . if pli0043_`x' < 0
replace pli0043_`x' = 12 if pli0043_`x' > 12 & pli0043_`x' < .
clonevar hw_`x' = pli0043_`x'
}
*			

* Errands
foreach x of numlist 1/2 {
replace pli0040_`x' = 0 if pli0040_`x' == -2			
replace pli0040_`x' = . if pli0040_`x' < 0
replace pli0040_`x' = 12 if pli0040_`x' > 12 & pli0040_`x' < .
clonevar err_`x' = pli0040_`x'
}
*	

* Repairs and garden work
foreach x of numlist 1/2 {
replace pli0049_`x' = 0 if pli0049_`x' == -2			
replace pli0049_`x' = . if pli0049_`x' < 0
replace pli0049_`x' = 12 if pli0049_`x' > 12 & pli0049_`x' < .
clonevar rep_`x' = pli0049_`x'
}
*	

* Define variables for husband and wife
rename ple0008_1 srh_1
	rename ple0008_2 srh_2
		rename plh0174_1 sat_1
			rename plh0174_2 sat_2
local X = "hw err rep age srh sat"
foreach x of local X {
gen `x'_h = .
gen `x'_w = .
replace `x'_h = `x'_1 if sex_1 == 1
replace `x'_h = `x'_2 if sex_2 == 1
replace `x'_w = `x'_1 if sex_1 == 2
replace `x'_w = `x'_2 if sex_2 == 2
}

* Define missings and labels
foreach var of varlist srh_h srh_w sat_h sat_w {
replace `var' = . if `var' < 0
}
drop age_1-rep_2
label define h 1 "Very good" 2 "Good" 3 "Satisfactory" 4 "Poor" 5 "Bad", replace	
label values srh_w h
label values srh_h h

* Keep only observations in which all key variables are non-missing
keep if !missing(hw_h, hw_w, err_h, err_w, rep_h, rep_w, srh_h, srh_w)


* Define total couple hours, within-couple shares and logged hours
local X = "hw err rep"
foreach x of local X {
gen `x'_c = `x'_h + `x'_w
gen `x's_h = `x'_h/`x'_c	
gen `x's_w = `x'_w/`x'_c		
gen `x'_hl = log(`x'_h+1)	
gen `x'_wl = log(`x'_w+1)
}	

* Domestic outsourcing
recode hlf0261_1 (-1 -8 = .) (1=2 "Regularly") (2=1 "Occasionally") (3=0 "No"), gen(help)	
gen size = hgsize_1/20		
gen out = .
replace out = 1 if inlist(help,1,2)
replace out = 0 if help == 0

* Categorical age
egen cage_w = cut(age_w), at(60(5)85)
	replace cage_w = 80 if cage_w == . // set 85 to top category
egen cage_h = cut(age_h), at(60(5)85)
	replace cage_h = 80 if cage_h == . // set 85 to top category

*-------------------------------------------------------------------------------------*
*-------------------------------------------------------------------------------------*

save "$posted/data.dta", replace

*-------------------------------------------------------------------------------------*
*-------------------------------------------------------------------------------------*

